@@ -1,5 +1,5 @@
 # opa: An Implementation of Ordinal Pattern Analysis.
-# Copyright (C) 2022 Timothy Beechey (tim.beechey@protonmail.com)
+# Copyright (C) 2022 Timothy Beechey (tim.beechey@proton.me)
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,13 +34,14 @@ row_pcc <- function(xs, h, pairing_type, diff_threshold) {
 
   n_pairs <- length(match)
   correct_pairs <- sum(match)
-  pcc <- mean(match) * 100
+  pcc <- (correct_pairs/n_pairs) * 100
 
   list(pcc = pcc,
        n_pairs = n_pairs,
        correct_pairs = correct_pairs)
 }
 
+
 pcc <- function(dat, h, pairing_type, diff_threshold) {
 
   individual_pccs <- numeric(dim(dat)[1])
